@@ -114,6 +114,9 @@ class ApiList(View):
         return settings.SITE.kernel.run_action(ar)
 
     def get(self, request, app_label=None, actor=None):
+        vm = test_version_mismatch(request)
+        if vm:
+            return json_response(vm)
         ar = action_request(app_label, actor, request, request.GET, True)
         # Add this hack to support the 'sort' param which is different in Extjs6.
         # if ar.order_by and ar.order_by[0]:
@@ -143,11 +146,6 @@ class ApiList(View):
             if isinstance(ar.bound_action.action, ShowEmptyTable):
                 elem = ar.create_instance()
                 datarec = elem2rec_empty(ar, ar.ah, elem)
-                vm = test_version_mismatch(request)
-                if vm:
-                    datarec.update(vm)
-                    resp = json_response(datarec)
-                    return resp
                 return json_response(datarec)
 
             display_mode = request.GET.get(
@@ -164,16 +162,7 @@ class ApiList(View):
                 def serialize(ar, row):
                     """Use display_mode to determine which serilisation store method and fields to use"""
                     if display_mode == constants.DISPLAY_MODE_TABLE:
-                        row_classes = None
-                        if ar.actor.get_row_classes is not None and not isinstance(row, PhantomRow):
-                            classes = ar.actor.get_row_classes(row, ar)
-                            if isinstance(classes, GeneratorType):
-                                row_classes = " ".join([klass for klass in classes])
-                            else:
-                                row_classes = classes
-                        rowData = rh.store.row2list(ar, row)
-                        rowData.append(row_classes)
-                        return rowData
+                        return rh.store.row2list(ar, row)
                     elif display_mode == constants.DISPLAY_MODE_GALLERY:
                         # return rh.store.file2url(ar, row)
                         return row.get_gallery_item(ar)
@@ -212,11 +201,6 @@ class ApiList(View):
                 kw.update(
                     param_values=ar.actor.params_layout.params_store.pv2dict(
                         ar, ar.param_values))
-            vm = test_version_mismatch(request)
-            if vm:
-                kw.update(vm)
-                resp = json_response(kw)
-                return resp
             return json_response(kw)
 
         return settings.SITE.kernel.run_action(ar)
